import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_autoscaling._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_deployment._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@pepperize/cdk-autoscaling-gitlab-runner",
    "0.0.93",
    __name__[0:-6],
    "cdk-autoscaling-gitlab-runner@0.0.93.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
